Learn R Programming

DEGreport (version 1.8.2)

degMV: Correlation of the standard desviation and the mean of the abundance of a set of genes.

Description

Correlation of the standard desviation and the mean of the abundance of a set of genes.

Usage

degMV(g1,g2,pvalues,counts)

Arguments

g1
list of samples in group 1
g2
list of samples in group 2
pvalues
pvalues of DEG analysis
counts
matrix with counts for each samples and each gene. row number should be the same length than pvalues vector.

Value

ggplot2 object

Examples

Run this code
data(DEGreportSet)
degMV(DEGreportSet$g1,DEGreportSet$g2,DEGreportSet$deg[,4],
    DEGreportSet$counts)

Run the code above in your browser using DataLab