Learn R Programming

DEGreport (version 1.8.2)

figurebyvar: Wrap figure from degVB into a Nozzle object

Description

Wrap figure from degVB into a Nozzle object

Usage

figurebyvar(tags, g1, g2, counts, out, pop = 400)

Arguments

tags
genes of DEG analysis
g1
group 1
g2
group 2
counts
matrix with counts for each samples and each gene. Row number should be the same length than pvalues vector.
out
path to save the figure
pop
random genes for background

Value

Nozzle object